==> j2sdk-1_4_2_03-i586-1.tgz: com/sun/java/swing/plaf/gtk/resources/gtk_sv.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk_sv extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "*" },
        { "FileChooser.cancelButtonText", "Avbryt" },
        { "FileChooser.cancelButtonToolTipText", "St\u00E4ng dialogrutan f\u00F6r filval." },
        { "FileChooser.deleteFileButtonText", "Ta bort fil" },
        { "FileChooser.filesLabelText", "Filer" },
        { "FileChooser.foldersLabelText", "Mappar" },
        { "FileChooser.newFolderButtonText", "Ny mapp" },
        { "FileChooser.openButtonText", "OK" },
        { "FileChooser.openButtonToolTipText", "\u00D6ppna den markerade filen." },
        { "FileChooser.openDialogTitleText", "\u00D6ppna" },
        { "FileChooser.pathLabelText", "Markeringen:" },
        { "FileChooser.renameFileButtonText", "Byt namn p\u00E5 fil" },
        { "FileChooser.saveButtonText", "Spara" },
        { "FileChooser.saveButtonToolTipText", "Spara den markerade filen." },
        { "FileChooser.saveDialogTitleText", "Spara" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "Bl\u00E5:" },
        { "GTKColorChooserPanel.colorNameMnemonic", "70" },
        { "GTKColorChooserPanel.colorNameText", "F\u00E4rgnamn:" },
        { "GTKColorChooserPanel.greenMnemonic", "71" },
        { "GTKColorChooserPanel.greenText", "Gr\u00F6n:" },
        { "GTKColorChooserPanel.hueMnemonic", "78" },
        { "GTKColorChooserPanel.hueText", "Nyans:" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "GTK F\u00E4rgv\u00E4ljaren" },
        { "GTKColorChooserPanel.redMnemonic", "82" },
        { "GTKColorChooserPanel.redText", "R\u00F6d:" },
        { "GTKColorChooserPanel.saturationMnemonic", "77" },
        { "GTKColorChooserPanel.saturationText", "M\u00E4ttnad:" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "V\u00E4rde:" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}

==> j2sdk-1_5_0_01-i586-1.tgz: com/sun/java/swing/plaf/gtk/resources/gtk_sv.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk_sv extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "Alla filer" },
        { "FileChooser.cancelButtonText", "Avbryt" },
        { "FileChooser.cancelButtonToolTipText", "St\u00E4ng dialogrutan f\u00F6r filval." },
        { "FileChooser.deleteFileButtonText", "Ta bort fil" },
        { "FileChooser.filesLabelText", "Filer" },
        { "FileChooser.filterLabelText", "Filter:" },
        { "FileChooser.foldersLabelText", "Mappar" },
        { "FileChooser.newFolderButtonText", "Ny mapp" },
        { "FileChooser.newFolderDialogText", "Mapp:" },
        { "FileChooser.openButtonText", "OK" },
        { "FileChooser.openButtonToolTipText", "\u00D6ppna den markerade filen." },
        { "FileChooser.openDialogTitleText", "\u00D6ppna" },
        { "FileChooser.pathLabelText", "Markeringen:" },
        { "FileChooser.renameFileButtonText", "Byt namn p\u00E5 fil" },
        { "FileChooser.renameFileDialogText", "Byt namn p\u00E5 fil \"{0}\" till" },
        { "FileChooser.renameFileErrorText", "Det gick inte att byta namn p\u00E5 fil \"{0}\" till \"{1}\"" },
        { "FileChooser.renameFileErrorTitle", "Fel" },
        { "FileChooser.saveButtonText", "Spara" },
        { "FileChooser.saveButtonToolTipText", "Spara den markerade filen." },
        { "FileChooser.saveDialogTitleText", "Spara" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "Bl\u00E5:" },
        { "GTKColorChooserPanel.colorNameMnemonic", "70" },
        { "GTKColorChooserPanel.colorNameText", "F\u00E4rgnamn:" },
        { "GTKColorChooserPanel.greenMnemonic", "71" },
        { "GTKColorChooserPanel.greenText", "Gr\u00F6n:" },
        { "GTKColorChooserPanel.hueMnemonic", "78" },
        { "GTKColorChooserPanel.hueText", "Nyans:" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "GTK F\u00E4rgv\u00E4ljaren" },
        { "GTKColorChooserPanel.redMnemonic", "82" },
        { "GTKColorChooserPanel.redText", "R\u00F6d:" },
        { "GTKColorChooserPanel.saturationMnemonic", "77" },
        { "GTKColorChooserPanel.saturationText", "M\u00E4ttnad:" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "V\u00E4rde:" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}
